@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2013 Peter Selinger.
+/* Copyright (C) 2001-2015 Peter Selinger.
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
@@ -15,7 +15,11 @@
 #ifdef __MINGW32__
 #include <fcntl.h>
 unsigned int _CRT_fmode = _O_BINARY;
-#endif
+static inline void platform_init(void) {
+  _setmode(_fileno(stdin), _O_BINARY);
+  _setmode(_fileno(stdout), _O_BINARY);
+}
+#else
 
 #ifdef __CYGWIN__
 #include <fcntl.h>
@@ -29,5 +33,6 @@ static inline void platform_init(void) {
   /* NOP */
 }
 #endif
+#endif
 
 #endif /* PLATFORM_H */
